@@ -1,21 +1,21 @@
 use strict;
 use warnings;
-package Test::JSON::Schema::Acceptance; # git description: v0.990-35-g59e0a4f
+package Test::JSON::Schema::Acceptance; # git description: v0.991-12-ge50ddad
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Acceptance testing for JSON-Schema based validators like JSON::Schema
 
-our $VERSION = '0.991';
+our $VERSION = '0.992';
 
 no if "$]" >= 5.031009, feature => 'indirect';
 use Test::More ();
 use Test::Fatal ();
-use JSON::MaybeXS;
+use JSON::MaybeXS 1.004001;
 use File::ShareDir 'dist_dir';
 use Moo;
 use MooX::TypeTiny 0.002002;
-use Types::Standard qw(Str InstanceOf ArrayRef HashRef Dict Any HasMethods);
+use Types::Standard 1.010002 qw(Str InstanceOf ArrayRef HashRef Dict Any HasMethods);
 use Path::Tiny;
-use List::Util 'any';
+use List::Util 1.33 'any';
 use namespace::clean;
 
 has specification => (
@@ -30,7 +30,7 @@ has test_dir => (
   isa => InstanceOf['Path::Tiny'],
   coerce => sub { path($_[0])->absolute('.') },
   lazy => 1,
-  default => sub { path(dist_dir('Test-JSON-Schema-Acceptance'),'tests', $_[0]->specification) },
+  default => sub { path(dist_dir('Test-JSON-Schema-Acceptance'), 'tests', $_[0]->specification) },
 );
 
 around BUILDARGS => sub {
@@ -66,13 +66,15 @@ sub _run_tests {
 
   warn "'skip_tests' option is deprecated" if $options->{skip_tests};
 
+  my %results; # results by file
+
   foreach my $one_file (@$tests) {
     next if $options->{tests} and $options->{tests}{file}
       and not grep $_ eq $one_file->{file},
         (ref $options->{tests}{file} eq 'ARRAY'
           ? @{$options->{tests}{file}} : $options->{tests}{file});
 
-    foreach my $test_group (@{$one_file->{json}}){
+    foreach my $test_group (@{$one_file->{json}}) {
       next if $options->{tests} and $options->{tests}{group_description}
         and not grep $_ eq $test_group->{description},
           (ref $options->{tests}{group_description} eq 'ARRAY'
@@ -96,24 +98,30 @@ sub _run_tests {
             }
             @{$options->{todo_tests}};
 
-        $self->_run_test($one_file, $test_group, $test, $options);
+        my $result = $self->_run_test($one_file, $test_group, $test, $options);
+        ++$results{$one_file->{file}}->{ $result ? 'pass' : 'fail' };
       }
     }
   }
+
+  Test::More::note '';
+  Test::More::note sprintf('%-25s pass  fail', 'filename');
+  Test::More::note '-'x36;
+  Test::More::note sprintf('%-25s  %3d   %3d', $_, $results{$_}{pass} // 0, $results{$_}{fail} // 0)
+    foreach sort keys %results;
+  Test::More::note '';
 }
 
 sub _run_test {
   my ($self, $one_file, $test_group, $test, $options) = @_;
 
-  local $Test::Builder::Level = $Test::Builder::Level + 3;
-
   TODO: {
     local $::TODO = 'Test marked TODO via "skip_tests"'
       if ref $options->{skip_tests} eq 'ARRAY' and
         grep +(($test_group->{description}.' - '.$test->{description}) =~ /$_/), @{$options->{skip_tests}};
 
     my $result;
-    my $exception = Test::Fatal::exception{
+    my $exception = Test::Fatal::exception {
       $result = $options->{validate_data}
         ? $options->{validate_data}->($test_group->{schema}, $test->{data})
         : $options->{validate_json_string}->($test_group->{schema}, $self->_json_decoder->encode($test->{data}));
@@ -122,8 +130,13 @@ sub _run_test {
     my $got = $result ? 'true' : 'false';
     my $expected = $test->{valid} ? 'true' : 'false';
 
-    Test::More::is($got, $expected, $one_file->{file}.': "'.$test_group->{description}.'" - "'.$test->{description}.'"');
-    Test::More::fail($exception) if $exception;
+    local $Test::Builder::Level = $Test::Builder::Level + 3;
+
+    my $pass = Test::More::is($got, $expected,
+      $one_file->{file}.': "'.$test_group->{description}.'" - "'.$test->{description}.'"');
+    $pass = Test::More::fail($exception) if $exception;
+
+    return $pass;
   }
 }
 
@@ -140,7 +153,7 @@ has _test_data => (
            file => Str,
            json => ArrayRef[Dict[
              description => Str,
-             (schema => InstanceOf['JSON::PP::Boolean']|HashRef),
+             schema => InstanceOf['JSON::PP::Boolean']|HashRef,
              tests => ArrayRef[Dict[
                data => Any,
                description => Str,
@@ -184,7 +197,7 @@ Test::JSON::Schema::Acceptance - Acceptance testing for JSON-Schema based valida
 
 =head1 VERSION
 
-version 0.991
+version 0.992
 
 =head1 SYNOPSIS
 
@@ -286,7 +299,7 @@ C<draft3> through C<draft7>.)
 =head2 test_dir
 
 Instead of specifying a draft specification to test against, which will select the most appropriate tests,
-you can pass in the name of a directory of tests to run directly.  Files in this directory should be F<.json>
+you can pass in the name of a directory of tests to run directly. Files in this directory should be F<.json>
 files following the format described in
 L<https://github.com/json-schema-org/JSON-Schema-Test-Suite/blob/master/README.md>.
 
@@ -325,7 +338,7 @@ Either C<validate_data> or C<validate_json_string> is required.
 
 =head3 tests
 
-Optional.  Restricts tests to just those mentioned (the conditions are ANDed together, not ORed).
+Optional. Restricts tests to just those mentioned (the conditions are ANDed together, not ORed).
 The syntax can take one of many forms:
 
   # run tests in this file
@@ -385,7 +398,7 @@ Various others in #perl-help.
 
 =head1 SUPPORT
 
-bugs may be submitted through L<https://github.com/karenetheridge/Test-JSON-Schema-Acceptance/issues>.
+Bugs may be submitted through L<https://github.com/karenetheridge/Test-JSON-Schema-Acceptance/issues>.
 
 =head1 AUTHOR
 
@@ -393,17 +406,17 @@ Ben Hutton (@relequestual) <relequest@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Ben Hutton Karen Etheridge Daniel Perrett
+=for stopwords Karen Etheridge Ben Hutton Daniel Perrett
 
 =over 4
 
 =item *
 
-Ben Hutton <relequestual@gmail.com>
+Karen Etheridge <ether@cpan.org>
 
 =item *
 
-Karen Etheridge <ether@cpan.org>
+Ben Hutton <relequestual@cpan.org>
 
 =item *
 
